#
# spec file for package pound
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1230
%bcond_without systemd
%else
%bcond_with    systemd
%endif
Name:           pound
Version:        2.8
Release:        bp156.3.20
Summary:        Reverse proxy and load balancer
License:        SUSE-GPL-3.0+-with-openssl-exception
Group:          Productivity/Networking/Web/Proxy
URL:            http://www.apsis.ch/pound/
Source0:        http://www.apsis.ch/pound/Pound-%{version}.tgz
Source1:        pound.cfg
Source2:        init.pound
Source3:        %{name}.service
Patch0:         pound.diff
# PATCH-FIX-UPSTREAM add-openssl_1.1-support.patch
Patch1:         add-openssl_1.1-support.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
Requires(pre):  shadow
%if %{with systemd}
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%else
Requires(pre):         %insserv_prereq
%endif

%description
The Pound program is a reverse proxy, load balancer and HTTPS front-end
for Web server(s). Pound was developed to enable distributing the load
among several web servers and to allow for a convenient SSL wrapper for
those web servers that do not offer it natively.

%package doc
Summary:        Doumentation for pound
Group:          Documentation/Other

%description doc
The Pound program is a reverse proxy, load balancer and HTTPS front-end
for web server(s). Pound was developed to enable distributing the load
among several web servers and to allow for a convenient SSL wrapper for
those web servers that do not offer it natively.

This package contains the documentation for pound.

%prep
%setup -q -n Pound-%{version}
%patch0
%patch1 -p1

%build
%configure \
  --enable-msdav \
  --with-ssl=%{_includedir}/openssl \
  --with-owner=pound \
  --with-group=pound
make %{?_smp_mflags}

%install
%make_install
# Install pound init script
%if %{with systemd}
install -Dm 0644 %{SOURCE3} %{buildroot}/%{_unitdir}/pound.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
install -Dm 0744 %{SOURCE2} %{buildroot}%{_initddir}/pound
ln -sf ../..%{_initddir}/pound %{buildroot}%{_sbindir}/rcpound
%endif
install -Dm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pound.cfg
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}/examples
install -m644 GPL.txt README FAQ %{buildroot}%{_defaultdocdir}/%{name}/
install -m755 z2_2_5_1.py z2_2_6_1.py %{buildroot}%{_defaultdocdir}/%{name}/examples/

%pre
# Add the "pound" user and group
getent group pound >/dev/null || %{_sbindir}/groupadd -r pound
getent passwd pound >/dev/null || \
	%{_sbindir}/useradd -c "Pound" -g pound -r -d %{_localstatedir}/lib/pound pound
%if %{with systemd}
%service_add_pre %{name}.service
%endif

%post
%if %{with systemd}
%service_add_post %{name}.service
%else
%{fillup_and_insserv -f -n pound pound}
%endif

%postun
%if %{with systemd}
%service_del_postun %{name}.service
%else
%restart_on_update pound
%insserv_cleanup
%endif

%preun
%if %{with systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal pound
%endif

%files
%doc %{_defaultdocdir}/%{name}/GPL.txt
%if %{with systemd}
%{_unitdir}/%{name}.service
%else
%{_initddir}/pound
%endif
%attr(555, root, root) %{_sbindir}/pound
%attr(555, root, root) %{_sbindir}/poundctl
%{_sbindir}/rcpound
%{_mandir}/man8/pound.8%{?ext_man}
%{_mandir}/man8/poundctl.8%{?ext_man}
%config(noreplace) %{_sysconfdir}/pound.cfg

%files doc
%doc %{_defaultdocdir}/%{name}
%exclude %{_defaultdocdir}/%{name}/GPL.txt

%changelog
* Fri Apr 26 2019 mvetter@suse.com
- bsc#1130588: Require shadow instead of old pwdutils
* Mon Apr  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.8
  * removed DynScale flag and support
  * removed support for multi-line headers (both input and output)
  * CVE-2018-21245: fixed potential request smuggling via fudged headers (boo#1173075)
- Add add-openssl_1.1-support.patch to fix bnc#1116061
  (Patch from https://github.com/graygnuorg/pound, mentioned here:
  http://www.apsis.ch/pound/pound_list/archive/2019/2019-02/1550768278000#1550768278000)
- Run spec-cleaner
* Wed Oct 31 2018 olaf@aepfle.de
- Fix libopenssl dependency, add openssl
* Wed Jan 31 2018 idonmez@suse.com
- Depend on openssl 1.0
* Tue Jan 30 2018 jengelh@inai.de
- Do not ignore errors from useradd
- Fix grammar errors in description
* Tue Jan 30 2018 kbabioch@suse.com
- Update to version 2.8a
  * removed DynScale flag and support
  * fixed potential request smuggling via fudged headers (CVE-2016-10711
    boo#1078298)
* Mon Aug  1 2016 joe@suse.com
- Corrected path in pound.service file from /usr/bin/pound to
  /usr/sbin/pound.
* Thu Mar 12 2015 p.drouand@gmail.com
- Update to version 2.7
  * added support for larger DH keys + compile-time parameter for
    DH bits (workaround for OpenSSL limitation)
  * added support for elliptical curve encryption
  * added protocol version in X-SSL-cipher
  * added "Disable PROTO" directives (fix for Poodle vulnerability)
  * added Cert, Disable and Cipher directives for HTTPS back-ends.
    The directive HTTPS "cert" no longer supported.
  * added filtering of "Expect: 100-continue" headers
  * Add support for PATCH HTTP method
  * Anonymise configuration option - show last client address byte as 0
  * SSLAllowClientRenegotiation
  * SSLHonorCipherOrder
  * Certificate alternate names support
  * poundctl shows the length of the request queue
  * fixed lh_retrieve warning
  * fixed potential memory leak on client certificates
  * fixed alt names problem
  * removed debugging messages
  * fixed address comparison for RewriteLocation (IPv4/IPv6 problem)
  * re-patched the redirect patch (Frank Schmierler)
  * fixed RPC handling
  * sanitize URLs for redirection (prevent CSRF)
  * SSL disable empty fragments + SSL disable compression
    (CRIME attack prevention)
  * fixed bug in configuration of DISABLED directive
  * changed the log level from WARNING to NOTICE if the thread arg is NULL
  * fixed testing of gcc options
- Add systemd support for openSUSE > 12.3
* Fri Apr 20 2012 bwiedemann@suse.com
- upgrade to version 2.6
* Fri Feb 17 2012 cfarrell@suse.com
- license update: SUSE-GPL-3.0+-with-openssl-exception
  Use SUSE- proprietary prefix until SPDX upstream accepts the license
* Thu Apr 22 2010 meissner@suse.de
- fixed openssl 1.0 build with patch from redhat.
* Thu Aug  6 2009 joe@novell.com
- update to version 2.4.5 (various bug fixes, enhancements in
  xHTTP 3 and 4 support)
* Tue Aug 19 2008 joe@suse.de
- update to version 2.4.3 (various bug fixes, no new features)
* Wed Feb 13 2008 joe@suse.de
- update to version 2.4
  - now GPL v3 or later
  - new PARM session type
  - full IPv6 support
  - pountctl can show status as an XML file
  - shutdown grace period (Pound accepts requests for
    existing sessions for some time instead of doing a
    hard shutdown)
* Fri Nov  9 2007 lrupp@suse.de
- split of doc package
* Fri Nov  9 2007 crrodriguez@suse.de
- update to version 2.3.2
- add missing PreREq fixes build in BETA
- add missing init script short-description and remote_fs depss
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Mon Apr 30 2007 joe@suse.de
- update to version 2.3
  - dynamic scaling
  - various bugs fixed
- now using user/group "pound"
* Tue Feb  6 2007 joe@suse.de
- update to version 2.2.3
- new configuration file syntax
- added a new example configuration file
- added configtest option to init script
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jun  3 2005 joe@suse.de
- upgraded to version 1.9
- 1.9 contains the fix for CAN-2005-1391
* Sat Feb 12 2005 joe@suse.de
- upgraded to bugfix version 1.8.1
* Thu Sep 30 2004 joe@suse.de
- slightly more useful default configuration file that works out of
  the box
* Fri Sep 10 2004 joe@suse.de
- latest current snapshot
* Mon Apr 26 2004 joe@suse.de
- initial version of current Pound snapshot
* Fri Jan 23 2004 joe@suse.de
- upgraded to stable version 1.8
